# Runtime

Runtime describes a runtime to be used to support dataset
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**category** | **str** | Category the runtime object belongs to (e.g. Accelerate) | [optional] 
**master_replicas** | **int** | Runtime master replicas | [optional] 
**name** | **str** | Name of the runtime object | [optional] 
**namespace** | **str** | Namespace of the runtime object | [optional] 
**type** | **str** | Runtime object&#39;s type (e.g. Alluxio) | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


